@@ -1211,10 +1211,12 @@ def bundledExecutable(name):
 def execute(cmd, show=True):
     result = ""
     try:
+        startupinfo = subprocess.STARTUPINFO()
+        startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
         if os.name != "nt":
-            result = str(subprocess.check_output(shlex.split(cmd)))
+            result = str(subprocess.check_output(shlex.split(cmd), startupinfo=startupinfo))
         else:
-            result = str(subprocess.check_output(cmd))
+            result = str(subprocess.check_output(cmd, startupinfo=startupinfo))
     except FileNotFoundError:
         logError("Command too long:", len(cmd), cmd)
         if result != "":
